pub(crate) struct GenerateShadowfork {
output: PathBuf,
force: bool,
source_chain: String,
execution_datadir: PathBuf,
block: BlockTarget,
preserve_chain_id: bool,
genesis_args: GenesisArgs,
}Expand description
Generates artifacts for a private shadow fork from a local Tempo execution datadir.
The source node must be stopped before using its datadir. The resulting network is expected to run private consensus from the generated artifacts and not follow the source chain after startup.
Fields
output: PathBufThe target directory that will be populated.
If this directory exists but is not empty the operation will fail unless --force
is specified. In this case the target directory will be first cleaned.
force: boolWhether to overwrite output.
source_chain: StringHuman-readable source chain name recorded in the manifest.
execution_datadir: PathBufSource execution datadir, chain datadir, or db directory to fork from.
block: BlockTargetSource block to fork from: latest, a decimal block number, or a block hash.
The selected block must be the local datadir tip.
preserve_chain_id: boolKeep the source chain ID in the generated genesis.
genesis_args: GenesisArgsImplementations